#!/usr/local/bin/python
from __future__ import print_function, division
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.ticker import AutoMinorLocator


filename = "DetEnergyDepLon.txt"
f = open(filename)

zbin = []
edep = []

for line in f.readlines():
    if line[0] != "#":
        line = line.split(',')

        zbin_i = int(line[2])
        edep_i = float(line[3])

        zbin.append(zbin_i)
        edep.append(edep_i)

zbin = np.array(zbin)
edep = np.array(edep)


binsize = 0.2    # mm
z = zbin*binsize

emax = np.max(edep) 
zpeak =  float(z[np.where(edep == emax)]) # find position of Bragg peak


plt.title("Energy deposition in detector")

plt.xlabel("Depth [mm]")
plt.ylabel("Energy deposited [MeV]")

plt.scatter(z, edep, s=10, facecolor='b', lw=0)


# make axes more legible
ax = plt.gca()
ax.xaxis.set_minor_locator(AutoMinorLocator(2))
ax.yaxis.set_minor_locator(AutoMinorLocator(2))

plt.ticklabel_format(style='sci', axis='y', scilimits=(0,0))

plt.xlim(0, 40)
plt.ylim(0, plt.ylim()[1])


# draw line at Bragg peak
plt.vlines(zpeak, 0, emax*1.5, linestyle='dashed', label='Bragg peak at %.1f mm' % (zpeak))

plt.legend(loc=2)

plt.grid()


plt.savefig("plots/" + filename[:-4] + ".png", dpi=600)
