# This is a template job submission script. The variable i is set when
# simulations are submitted in submit.sh.
# ------------------------------------------------------------------------------
# Author: 07/07/2017, M. Hentz
# Modified:
#   <date>, <initials> <name>
# ------------------------------------------------------------------------------
#!/bin/bash

#PBS -l nodes=1:ppn=1
#PBS -o log/${i}.log
#PBS -e err/${i}.err

# Use submission environment
#PBS -V

# Set seeds to i and i + 100
seed1_cb=${i}
seed2_cb=`expr $seed1 + 100`

# Get number of events
nevents_cb=${nlines}

# Get base directory
basedir=$(dirname $PBS_O_WORKDIR)

# Assign seeds to variables and write to macro for given job
# Use # in sed substitution to avoid conflict with /
cd $PBS_O_WORKDIR
cat ../proton.mac | sed -e "s/\${seed1}/${seed1_cb}/" \
-e "s/\${seed2}/${seed2_cb}/" -e "s/\${nevents}/${nevents_cb}/" \
-e "s#\${wd}#${basedir}#" >> proton${i}.mac

# Create directory to save outputs in
if [[ -d $PBS_O_WORKDIR/sims/${i} ]]; then
    rm -r $PBS_O_WORKDIR/sims/${i}
fi
mkdir $PBS_O_WORKDIR/sims/${i}
cd $PBS_O_WORKDIR/sims/${i}
mkdir data

# Time run using SECONDS
SECONDS=0

# Start job in directory it was submitted from
$PBS_O_WORKDIR/clatterbridgeSim $PBS_O_WORKDIR/proton${i}.mac

# Remove macro after simulation has completed
rm $PBS_O_WORKDIR/proton${i}.mac

# Calculate and print time taken
duration=$SECONDS
printf "\n\nRuntime: $duration s"
printf "\nTime taken: %02d:%02d:%02d" $((duration / 3600)) $(( ($duration % 3600) / 60)) $(($duration % 60));
