# This script creates a timestamped directory and runs a given number of
# simulations in "parallel" in that directory. The /random/setSeeds and
# /run/beamOn command in the proton.mac macro should be changed accordingly.
# If primaries are read from a file, set the -r flag on the submit.sh script.
# Make sure to split the file into equally sized chunks for each simulation
# using the split_input.sh script.
# Usage: ./run.sh
# ------------------------------------------------------------------------------
# Author: 07/07/2017, M. Hentz
# Modified:
#   07/03/2018, M. Hentz
# ------------------------------------------------------------------------------
#!/bin/bash

# Save current date and time
timestamp=`date +%Y%m%d_%H%M%S`

# Create timestamped directory and copy binary and macro to it
mkdir $timestamp
cp -t $timestamp clatterbridgeSim proton.mac gps.mac

# Change to timestamped directory
cd $timestamp

# A note can be passed as a single command line argument (put quotation marks
# arond the whole thing) to describe the run. This is written to notes.txt
echo $1 > notes.txt

# Make directories for simulations, log files, error dumps, combined data,
# plots of combined data
mkdir sims
mkdir log
mkdir err
mkdir combined
mkdir combined/plots

# Copy submission script and script used to concatenate data into cd
cp ../cb_parallel.sh .
cp ../combine.sh .

# Submit a given number of simulations to a given queue
# If reading primaries from a file, set the split option
../submit.sh short 150
#../submit.sh short 150 -r
