# This script determines how many lines of a given input file should be passed
# onto each simulation given a number of simulations and splits the file into
# the respective parts. The chunks are written to files in ./read and
# are called xxx.in
# Usage:
#  ./split_input.sh /path/to/file nsimulations
# ------------------------------------------------------------------------------
# Author: 07/07/2017, M. Hentz
# Modified:
#   <date>, <initials> <name>
# ------------------------------------------------------------------------------
#!/bin/bash

# Check if arguments were given
if [[ -z $1 ]]
then
    echo -n "No arguments supplied. Need to specify the input file and the "
    echo    "number of simulations used."
	  echo    "Usage:"
    echo    " ./split_input.sh /path/to/file nsimulations"
    exit
fi

# Check if number of simulations were given
if [[ -z $2 ]]; then
    echo "Need to specify the number of simulations used."
	  echo "Usage:"
    echo " ./split_input.sh /path/to/file nsimulations"
    exit
fi

# Make directory chunks will be written to
mkdir read

# Get input filename and number of simulations to distribute primaries across
filename=$1
nsimulations=$2

# Parse number of lines in the input file
nlines=$(($(wc -l $filename | awk '{ printf $1; }') - 1))

# Calculate lines per simulation and remainder
lines_per_sim=$((nlines / nsim))
lines_remainder=$((nlines % nsim))

echo "There are $nlines lines in input:"
echo "  \"$filename\""
echo -n "For $nsimulations simulations that is $lines_per_sim lines per "
echo    "simulation with a remainder of $lines_remainder."

echo "Writing lines to separate files..."

# Iterate through nsimulations
for i in $(eval echo {1..$nsimulations}); do

    # If there is a remainder, add a line to the line count
    # and decrement remainder.
    # This will occur until all remaining lines have been assigned
  	if [[ $lines_remainder -ne 0 ]]; then
    		lines_assigned=$((lines_per_sim + 1))
    		lines_remainder=$((lines_remainder - 1))
  	fi

    # No more remaining lines
  	if [[ $lines_remainder -eq 0 ]]; then
  		  lines_assigned=$lines_per_sim
  	fi

    # Set high and low limits for each simulation
    # Lines from lim_lo to lim_hi are written to $i.in
  	lim_lo=$(( (i - 1)*lines_assigned + 3))
  	lim_hi=$(( i*lines_assigned + 2))

  	sed -n $(eval echo '${lim_lo},${lim_hi}p') $filename > read/$i.in

  	echo " $i.in done"
done

echo "Splitting done."
